from geox.factory.factory import Factory
from geox.project import Project
from geox.utils import convert_iso_8601_to_datetime


class ProjectFactory(Factory):
    def __init__(self):
        ...
    
    
    def create(self, data):
        project = None
        project_id = data['project_id'] if 'project_id' in data else None
        if project_id:
            project = Project(project_id)
            
            project.title = data['title'] \
                if 'title' in data else None

            project.location = data['location'] \
                if 'location' in data else None

            project.description = data['description'] \
                if 'description' in data else None

            project.num_of_project_versions = data['num_of_project_versions'] \
                if 'num_of_project_versions' in data else None

            project.created_at = convert_iso_8601_to_datetime(data['created_at']) \
                if 'created_at' in data else None

            project.updated_at = convert_iso_8601_to_datetime(data['updated_at']) \
                if 'updated_at' in data else None

        return project


from geox.factory.project_version_factory import ProjectVersionFactory
from geox.project_version import ProjectVersion


class HttpReponseProjectVersion():
    def __init__(self, json_response):
        self.project_version: ProjectVersion = None
        
        self._factory = ProjectVersionFactory()
        self._parser(json_response)
    
    
    def _parser(self, json_response):
        self.project_version = self._factory.create(json_response)



from geox.config import SERVER_HOST


class APIEndpoint:
    """Server endpoint, pointed to server host
    """
    __API_V1_EXTERNAL = SERVER_HOST + '/v1/geox'

    GET_INITIAL_AUTH = __API_V1_EXTERNAL + '/init'
    GET_USER_PROJECTS = __API_V1_EXTERNAL + '/project/all'
    GET_PROJECT = __API_V1_EXTERNAL + '/project'

    GET_PROJECT_VERSIONS = __API_V1_EXTERNAL + '/project/version/all'
    GET_PROJECT_VERSION = __API_V1_EXTERNAL + '/project/version'

    GET_COLLAR_DATA = __API_V1_EXTERNAL + '/dataset/collar'
    GET_SURVEY_DATA = __API_V1_EXTERNAL + '/dataset/survey'
    GET_ALTERATION_DATA = __API_V1_EXTERNAL + '/dataset/alteration'
    GET_ASSAY_DATA = __API_V1_EXTERNAL + '/dataset/assay'
    GET_LITHO_DATA = __API_V1_EXTERNAL + '/dataset/litho'
    GET_MINERALISATION_DATA = __API_V1_EXTERNAL + '/dataset/mineralisation'